==> happydigger_1.2.tar.gz: happydigger-1.2/src/callbacks.h <==
/*
 * happydigger - program for cataloging archaeological finds
 * Copyright (C) 2004 Joop Stakenborg <pg4i@amsat.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <gtk/gtk.h>

gboolean
on_fileselection_delete_event          (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_fileselection_ok_button_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_fileselection_cancel_button_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_firstbutton_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_previousbutton_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_nextbutton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_lastbutton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_ffbutton_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_rewindbutton_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_image1button_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_image2button_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_applybutton_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_listbutton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_removebutton_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_newbutton_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

gboolean
exit_program                           (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_prefsbutton_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_preferencesdialog_delete_event      (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_preferencescancelbutton_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_preferencesokbutton_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_helpbutton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_listwindow_delete_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

==> happydigger_2.1.orig.tar.gz: happydigger-2.1.orig/src/callbacks.h <==
/*
 * happydigger - program for cataloging archaeological finds
 * Copyright (C) 2004, 2005 Joop Stakenborg <pg4i@amsat.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Library General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <gtk/gtk.h>

gboolean
on_fileselection_delete_event          (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_fileselection_ok_button_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_fileselection_cancel_button_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_firstbutton_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_previousbutton_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_nextbutton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_lastbutton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_ffbutton_clicked                    (GtkButton       *button,
                                        gpointer         user_data);

void
on_rewindbutton_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_image1button_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_image2button_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_applybutton_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_listbutton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

void
on_removebutton_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_newbutton_clicked                   (GtkButton       *button,
                                        gpointer         user_data);

gboolean
exit_program                           (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_prefsbutton_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_preferencesdialog_delete_event      (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_preferencescancelbutton_clicked     (GtkButton       *button,
                                        gpointer         user_data);

void
on_preferencesokbutton_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_helpbutton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_listwindow_delete_event             (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_imagebutton1_clicked                (GtkButton       *button,
                                        gpointer         user_data);


void
on_imagebutton2_clicked                (GtkButton       *button,
                                        gpointer         user_data);

void
on_fileselection_cancel_button_clicked (GtkButton       *button,
                                        gpointer         user_data);

void
on_fileselection_ok_button_clicked     (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_fileselection_delete_event          (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

gboolean
on_imagewindow_keypress (GtkWidget *widget, GdkEventKey *event, gpointer data);

gboolean
on_imagewindow_delete_event            (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void on_list_select_row (GtkTreeSelection *selection, gpointer user_data);

void
on_newtablebutton_clicked              (GtkButton       *button,
                                        gpointer         user_data);

void
on_startbutton_clicked                 (GtkButton       *button,
                                        gpointer         user_data);

void
on_exitbutton_clicked                  (GtkButton       *button,
                                        gpointer         user_data);

gboolean
on_startupwindow_delete_event          (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data);

void
on_image1entry_changed                 (GtkEditable     *editable,
                                        gpointer         user_data);

void
on_image2entry_changed                 (GtkEditable     *editable,
                                        gpointer         user_data);
